// This file gets copied over to the native apps Content/pages directory as part
// of the build gradle tasks.
// This file contains functions that should not be modified as part of branding,
// therefore this file is not exposed to the branding pack.

var yudu_protocol = 'yudu:';

window.addEventListener('load', function() {
    // Enable setting latest edition data for a page
    setLatestEdition(getQueryParameterByName("latestEditionData"));

    // Enable executing javascript based on whether the user is logged in or not
    var loggedIn = getQueryParameterByName("loggedIn");
    if (loggedIn == "true") {
        if (typeof doIfUserIsLoggedIn === 'function') {
            doIfUserIsLoggedIn();
        }
    }
    else {
        if (typeof doIfUserIsNotLoggedIn === 'function') {
            doIfUserIsNotLoggedIn();
        }
    }

    // Enable the "log in" functionality on a page with a log in form
    var loginSubmitButton = document.querySelector('form[name="staticLogin"] input[name="logIn"]');
    if (loginSubmitButton) {
        loginSubmitButton.addEventListener("click", logInFromStaticPage);
    }

    // Enable the "forgotten password" functionality on a page with a log in form
    var forgottenPasswordButton = document.querySelector('form[name="staticLogin"] input[name="forgottenPassword"]');
    if (forgottenPasswordButton) {
        forgottenPasswordButton.addEventListener("click", forgottenPasswordClicked);
    }
});

/**
 * Sets the latest edition data on an in-app HTML page
 *
 * @param latestEditionData The latest edition data as JSON
 */
function setLatestEdition(latestEditionData) {
    if (latestEditionData) {
        if (typeof latestEditionData === 'string') {
            latestEditionData = JSON.parse(latestEditionData);
        }
    }
    else {
        latestEditionData = {};
    }

    if (!isEmpty(latestEditionData)) {
        var images = document.getElementsByClassName('thumbImage');
        for (var i = 0; i < images.length; i++) {
            images[i].src = latestEditionData.thumbUrl;
        }

        var latestLinks = document.getElementsByClassName('latestLink');
        for (var i = 0; i < latestLinks.length; i++) {
            latestLinks[i].href = yudu_protocol + 'goLatestEdition:' + 
                encodeURIComponent(latestEditionData.userId) + ':' + latestEditionData.editionId;
        }
    }

    var latestWrappers = document.getElementsByClassName('latestWrapper');
    for (var i = 0; i < latestWrappers.length; i++) {
        latestWrappers[i].style.display = isEmpty(latestEditionData) ? 'none' : 'block';
    }
}

/**
 * Searches a Uri for a query string parameter. If the parameter key exists, returns its value.
 * Note that this will only return the value for the first instance of a maching key.
 * If the key doesn't exist, returns null.
 *
 * @param name Key for which to retrieve value
 * @param url Uri from which to retrieve query string parameter value
 * @returns {*}
 */
function getQueryParameterByName(name, url) {
    if (!url) {
        url = window.location.href;
    }
    name = name.replace(/[\[\]]/g, "\\$&");
    var regex = new RegExp("[?&]" + name + "(?:=([^&#]*)|&|#|$)");
    var results = regex.exec(url);
    if (!results) {
        return null;
    }
    if (!results[1]) {
        return '';
    }
    return decodeURIComponent(results[1].replace(/\+/g, " "));
}

/**
 * Sends the user's credentials from a form to the server, allowing
 * logging in from a static HTML page
 */
function logInFromStaticPage() {
    var loginForm = document.querySelector('form[name="staticLogin"]');
    var usernameBox = loginForm.querySelector('input[name="username"]');
    var passwordBox = loginForm.querySelector('input[name="password"]');
    var username = encodeURIComponent(usernameBox.value);
    var password = encodeURIComponent(passwordBox.value);
    usernameBox.value = "";
    passwordBox.value = "";
    window.location.href = yudu_protocol + "goSubmitCredentials:" + username + ":" + password;
}

/**
 * Sends the user's username (typically an email address) to the server,
 * allowing the "forgotten password" functionality to be used in static HTML pages
 */
function forgottenPasswordClicked() {
    var loginForm = document.querySelector('form[name="staticLogin"]');
    var emailBox = loginForm.querySelector('input[name="username"]');
    var passwordBox = loginForm.querySelector('input[name="password"]');
    var email = encodeURIComponent(emailBox.value);
    emailBox.value = "";
    passwordBox.value = "";
    window.location.href = yudu_protocol + "goForgotPassword:" + email;
}

function isEmpty(obj) {
    for(var prop in obj) {
        if(obj.hasOwnProperty(prop)) {
            return false;
        }
    }

    return JSON.stringify(obj) === JSON.stringify({});
}
