// All the functions in this file are simply templates.
// Modify the insides of the functions to suit the client's needs.

/**
 * This function is called after the page has loaded if the user is logged in.
 * This function will only be called if the setting "sendUserCredentialsToInAppPages"
 * is set to true in the configValues.js file.
 *
 * @param username The user's username. Typically an email address.
 * @param password The user's password.
 */
function onUserCredentialsAvailable(username, password) {
    var testWrapper = document.getElementById("getUserCredentialsTestWrapper");
    if (testWrapper) {
        testWrapper.innerHTML = "You are currently logged in as user: " + username;
    }
}

/**
 * This function will always be called if the user is logged in.
 */
function doIfUserIsLoggedIn() {
    var logout = document.getElementById("logoutLink");
    if (logout) {
        logout.style.display = "inline";
    }
    var login = document.getElementById("loginLink");
    if (login) {
        login.style.display = "none";
    }
}

/**
 * This function will always be called if the user is NOT logged in.
 */
function doIfUserIsNotLoggedIn() {
    var login = document.getElementById("loginLink");
    if (login) {
        login.style.display = "inline";
    }
    var logout = document.getElementById("logoutLink");
    if (logout) {
        logout.style.display = "none";
    }
}

/**
 * This function is called after a user has attempted to log in or reset a forgotten password
 * on an html page. This function receives messages like "Error: invalid credentials" from the server,
 * which can then be displayed to the user.
 *
 * @param message The message sent back by the server after the user tried to either log in or
 *                reset their password.
 * @param type The type of message sent. This takes one of two values: "info" or "error"
 */
function onLoginIssue(message, type) {
    var messageClass = "loginMessage-" + type;
    var messageParagraph = document.querySelector('form[name="staticLogin"] p#loginInfoMessage');
    messageParagraph.removeAttribute("class");
    messageParagraph.setAttribute("class", messageClass);
    messageParagraph.innerHTML = message;
}